Learn R Programming

rscielo (version 1.0.0)

get_journal: Scrape meta-data from articles published by a journal hosted on Scielo

Description

get_journal() scrapes meta-data information from articles of a journal hosted on Scielo. In bilingual journals, articles' titles, abstracts and other relevant information are retrieved in the journal's main language used for publication (most of the time, it is English). The function can extract information from all articles ever published by the journal or only the ones in its latest issue.

Usage

get_journal(journal_id, last_issue = TRUE)

Arguments

journal_id

a character vector with the ID of the journal hosted on Scielo (the get_ournal_id function can be used to find the journal ID from its URL).

last_issue

a logical vector, if FALSE scrapes all issues of the journal, if TRUE (default) only scrapes its last issue.

Value

The function returns a tibble with the following variables:

  • author: Author name.

  • first_author_surname: First author surname.

  • institution: Author's institution.

  • inst_adress: Author's institution address.

  • country: Author's country.

  • title: Article title.

  • year: Year of publication.

  • journal: Journal name.

  • volume: Volume.

  • number: Number.

  • first_page: Article's first page.

  • last_page: Article's last page

  • abstratc: Article's abstract.

  • keywords: Article's keywords.

  • article_id:

  • doi: DOI.

  • n_authors: Number of authors.

  • n_pages: Number of pages.

  • n_refs: Number of references.

Details

This functions scrapes several meta-data information, such as author's names, articles' titles, year of publication, edition and number of pages, that can be summarized with specific summary method.

See Also

get_article_meta

Examples

Run this code
# NOT RUN {
df <- get_journal(journal_id = "1981-3821")
summary(df)
# }

Run the code above in your browser using DataLab