Learn R Programming

rscielo (version 1.0.0)

get_journal_info: Scrape the description of a journal hosted on Scielo

Description

get_journal_info() scrapes the description (publisher, issn, and mission) information of a journal hosted on Scielo.

Usage

get_journal_info(journal_id)

Arguments

journal_id

a character vector with the ID of the journal hosted on Scielo (the get_journal_id function can be used to find a journal's ID from its URL).

Value

The function returns a tibble with the journal's description.

Examples

Run this code
# NOT RUN {
journal_info <- get_journal_info(journal_id = "1981-3821")
# }

Run the code above in your browser using DataLab