Learn R Programming

rscielo (version 1.0.0)

get_journal_metrics: Scrape publication and citation counts of a journal hosted on Scielo

Description

get_journal_metrics() scrapes publication and citation counts of a jornal hosted on Scielo.

Usage

get_journal_metrics(journal_id)

Arguments

journal_id

a character vector with the ID of the journal hosted on Scielo (the get_journal_id function can be used to find a journal's ID from its URL).

Value

The function returns a tibble with the following variables:

  • year: Year.

  • n_issues: Number of issues in that year.

  • n_articles: Number of articles in that year.

  • granted_citations: Granted citations by the journal in that year.

  • received_citations: Received citations by the journal in that year.

  • avg_art_per_issues: Average number of articles published by the journal in that year.

Examples

Run this code
# NOT RUN {
df <- get_journal_metrics(journal_id = "1981-3821")
# }

Run the code above in your browser using DataLab